@@ -15,13 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
-// KDE includes
+// TDE includes
 #include <tdeapplication.h>
 #include <tdelocale.h>
 #include <tdeio/netaccess.h>
 #include <tdeio/job.h>
 
-// QT includes
+// TQt includes
 #include <tqeventloop.h>
 
 #include <tqfileinfo.h>
@@ -50,7 +50,7 @@ bool FileOperation::start( const KURL & src, const KURL & dest, int mode, bool o
     result = 0;
 
     if( src == dest && !overwrite ) {
-        m_error = TQString( i18n( "File %1 exists already!") ).arg( dest.prettyURL() );
+        m_error = i18n( "File %1 exists already!").arg( dest.prettyURL() );
         return false;
     }
     
@@ -83,8 +83,8 @@ bool FileOperation::start( const KURL & src, const KURL & dest, int mode, bool o
         return false;
         
     job->setAutoErrorHandlingEnabled( false, 0 );
-    connect( job, TQT_SIGNAL( result (TDEIO::Job *) ),
-           this, TQT_SLOT( slotResult (TDEIO::Job *) ) );
+    connect( job, TQ_SIGNAL( result (TDEIO::Job *) ),
+           this, TQ_SLOT( slotResult (TDEIO::Job *) ) );
 
     kapp->eventLoop()->enterLoop();
     return !result;
@@ -110,3 +110,4 @@ void FileOperation::slotResult( TDEIO::Job * job )
     kapp->eventLoop()->exitLoop();
 }
 
+#include "fileoperation.moc"
