@@ -38,7 +38,7 @@ class TQWidget;
 class TQVBoxLayout;
 class KFilePlugin;
 class FilePlugin : public Plugin  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         FilePlugin( KService* service );
