@@ -206,7 +206,7 @@ void KMyListBox::viewportMousePressEvent( TQMouseEvent* e )
         TQListBoxItem *i = itemAt( p );
         if ( i ) {
                 presspos = e->pos();
-                mousePressed = TRUE;
+                mousePressed = true;
         }
     }
 }
@@ -214,7 +214,7 @@ void KMyListBox::viewportMousePressEvent( TQMouseEvent* e )
 void KMyListBox::viewportMouseMoveEvent( TQMouseEvent* e )
 {
     if ( mousePressed && ( presspos - e->pos() ).manhattanLength() > TDEApplication::startDragDistance() ) {
-        mousePressed = FALSE;
+        mousePressed = false;
         TQListBoxItem *item = itemAt( presspos );
         if ( item ) {
             TQStringList source = text( index( item ) );
@@ -231,7 +231,7 @@ void KMyListBox::viewportMouseMoveEvent( TQMouseEvent* e )
 
 void KMyListBox::viewportMouseReleaseEvent( TQMouseEvent* e )
 {
-    mousePressed = FALSE;
+    mousePressed = false;
     TDEListBox::viewportMouseReleaseEvent( e );
 }
 
