@@ -33,7 +33,7 @@ class TQString;
 class TQVBoxLayout;
 class TQWidget;
 class MyDirPlugin : public Plugin  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         const TQString getName() const;
