@@ -27,7 +27,7 @@ class TQHBoxLayout;
 class TQString;
 class TQWidget;
 class PicturePlugin : public FilePlugin  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         PicturePlugin();
