@@ -49,7 +49,7 @@ class FileList : public TQPtrList<KFileItem> {
 
 class ThreadedLister : public TQObject, public TQThread
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         ThreadedLister( TQMutex* mutex, unsigned int* counter, KMyListBox* list );
