@@ -21,7 +21,7 @@
 #include <tqlabel.h>
 #include <tqlayout.h>
 
-// KDE includes
+// TDE includes
 #include <tdefiledialog.h>
 #include <tdelocale.h>
 #include <tdemessagebox.h>
@@ -59,8 +59,8 @@ UndoDialog::UndoDialog( TQWidget* parent )
 
     setButtonText( KDialogBase::User1, i18n( "&Start" ) );
 
-    connect( this, TQT_SIGNAL( user1Clicked() ), this, TQT_SLOT( start() ) );
-    connect( scriptname, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( enableControls() ) );
+    connect( this, TQ_SIGNAL( user1Clicked() ), this, TQ_SLOT( start() ) );
+    connect( scriptname, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( enableControls() ) );
 
     enableControls();
 }
@@ -89,9 +89,9 @@ void UndoDialog::start()
         return;
     }
     proc->resume();
-    connect( proc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int) ), this, TQT_SLOT( receive( TDEProcess*, char*, int ) ) );
-    connect( proc, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int) ), this, TQT_SLOT( receiveErr( TDEProcess*, char*, int ) ) );
-    connect( proc, TQT_SIGNAL( processExited( TDEProcess* ) ), this, TQT_SLOT( finished( TDEProcess* ) ) );
+    connect( proc, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int) ), this, TQ_SLOT( receive( TDEProcess*, char*, int ) ) );
+    connect( proc, TQ_SIGNAL( receivedStderr( TDEProcess*, char*, int) ), this, TQ_SLOT( receiveErr( TDEProcess*, char*, int ) ) );
+    connect( proc, TQ_SIGNAL( processExited( TDEProcess* ) ), this, TQ_SLOT( finished( TDEProcess* ) ) );
 }
 
 void UndoDialog::receive( TDEProcess*, char* buffer, int len )
@@ -131,6 +131,6 @@ void UndoDialog::setUndoScript( const TQString & filename )
     scriptname->setURL( filename );
 }
     
-
+#include "undodialog.moc"
 
 
